@@ -5,13 +5,24 @@
 # easily. [0/1] (0 = off and 1 = on)
 set wantgflag 1
 
+# Enable CTCP Cloaking? This will hide the fact that you have MOTD loaded
+# on an eggdrop bot in CTCP Version.  Useful to hide the bot from nosey
+# IRCops who go bot hunting ;-) (however I think that displaying a whole
+# file's worth of text to the person /join'ing a channel pretty much blows
+# it's cover anyways.) [0/1] (0 = off and 1 = on)
+set ctcpcloak 1
+
+# Set the follwing variable to the word of your bot (E.G. what you /msg it
+# to introduce yourself).
+set myword "hello"
+
 # If you have wantgflag set uncomment this. It's here cause you might
 # already have another custom flag bound to the default setting. Please
 # only change this if you know what your doing.
 set flag1 g
 
 # Set this to the location of your motd file. 
-set motdpath "/home/jl2/lib/egg1.15/tclmotd"
+set motdpath "/home/bots/bots/MasterP/test.motd"
 
 # Set this to 1 if you want CPU Awarness(tm).
 # 
@@ -20,8 +31,7 @@ set motdpath "/home/jl2/lib/egg1.15/tclmotd"
 #       tons of scripts loaded.
 # Cons: If you decide you want to change any of the settings in
 #       settings.tcl, you'll have to do a .rehash before the changes will
-#       take affect. If you like me and forget to .save when your
-#       addin/deleting users its bad =)
+#       take affect. 
 set cpuawarness 0
 
 # End configuration section. Don't change anthing below this line.
